@@ -2,12 +2,24 @@ use strict;
 use warnings FATAL => 'all';
 
 package MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::StringNumericLiteral::NativeNumberSemantics;
-use Data::Float qw//;
+use Data::Float qw/have_signed_zero have_infinite/;
 use Scalar::Util qw/blessed/;
+use Scalar::Util::Numeric qw/isinf/;
 
-# ABSTRACT: ECMAScript 262, Edition 5, lexical string numeric grammar default semantics package, using native perl number representations
+our $POS_ZERO = have_signed_zero() ? Data::Float::pos_zero() : 0.0;
+#
+# C.f. http://computer-programming-forum.com/53-perl/3bbc35c5223c25f7.htm
+# On some machine this may give 1.79769313486232e+308 (Alpha/HPUX), i.e.
+# when floats on are 64bits when ints are on 32bits
+#
+our $POS_INF_CANDIDATE1 = (~0)**(~0);
+our $POS_INF_CANDIDATE2 = do {my $n = 2; $n *= $n while $n < $n*$n; $n};
 
-our $VERSION = '0.008'; # TRIAL VERSION
+our $POS_INF  = have_infinite() ? Data::Float::pos_infinity() : (isinf($POS_INF_CANDIDATE1) ? $POS_INF_CANDIDATE1 : $POS_INF_CANDIDATE2);
+
+# ABSTRACT: ECMAScript 262, Edition 5, lexical string numeric grammar default semantics package, using native perl representations
+
+our $VERSION = '0.009'; # TRIAL VERSION
 
 
 
@@ -28,13 +40,13 @@ sub host_round {
 
 
 sub host_pos_zero {
-    $_[0]->{_number} = Data::Float::pos_zero();
+    $_[0]->{_number} = $POS_ZERO;
     return $_[0];
 }
 
 
 sub host_pos_inf {
-    $_[0]->{_number} = Data::Float::pos_infinity();
+    $_[0]->{_number} = $POS_INF;
     return $_[0];
 }
 
@@ -106,15 +118,15 @@ __END__
 
 =head1 NAME
 
-MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::StringNumericLiteral::NativeNumberSemantics - ECMAScript 262, Edition 5, lexical string numeric grammar default semantics package, using native perl number representations
+MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5::StringNumericLiteral::NativeNumberSemantics - ECMAScript 262, Edition 5, lexical string numeric grammar default semantics package, using native perl representations
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 DESCRIPTION
 
-This modules provide a default semantics package for the actions associated to ECMAScript_262_5 lexical string numeric grammar.
+This modules provide a default semantics package for the actions associated to ECMAScript_262_5 lexical string numeric grammar, using native number representation. This mean that the notion of Infinity, or positive zero, might not exactly follow ECMAScript specification (which restrict numbers to IEEE 32 bits floats).
 
 =head2 new($class)
 
@@ -130,11 +142,11 @@ Host implementation of rounded $self. Returns $self.
 
 =head2 host_pos_zero($self)
 
-Host implementation of $self setted to positive zero, defaulting to Data::Float::pos_zero(). Returns $self.
+Host implementation of $self setted to positive zero, defaulting to Data::Float::pos_zero if your host have signed zeroes, 0 otherwise. Returns $self.
 
 =head2 host_pos_inf($self)
 
-Host implementation of $self setted to positive infinity, defaulting to Data::Float::pos_infinity(). Return $self.
+Host implementation of $self setted to positive infinity, defaulting to Data::Float::pos_infinity if your host have infinity, otherwise a trial between (~0)**(~0) and {my $n = 2; $n *= $n while $n < $n*$n; $n}. Return $self.
 
 =head2 host_pow($self, $powobj)
 
